PlasmaPy v0.2.0 (2019-05-31)
============================

Version 0.2.0 is the second development release of PlasmaPy. Alongside a
few new features, it brings plentiful refactoring, documentation and
back stage improvements.

.. _change-log-0.2.0-new:

New Features
------------

- Implement machinery for a ``Plasma`` class factory based on
  `PLEP 6 <https://doi.org/10.5281/zenodo.1460977>`__
- Create an openPMD ``Plasma`` subclass
- Create classes to represent ionization state distributions for one
  or more elements or isotopes.
- Add basic particle drifts to ``plasmapy.physics.drifts``
- Turn most dependencies into optional, subpackage-specific ones

.. _change-log-0.2.0-bugfix:

Bug Fixes
---------

- Improve handling of NumPy arrays for plasma parameter and transport functions.
- Vendor the ``roman`` package so as to allow installation via Conda
- Decrease strictness of ``check_quantity`` to allow `~numpy.nan` and `~numpy.inf` by default

.. _change-log-0.2.0-api:

Changes to API
--------------

- Move ``plasmapy.transport`` from ``plasmapy.physics`` to its own
  subpackage.
